@@ -29,9 +29,9 @@ krscvNOMAD <- function(xz,
                        initial.mesh.size.real="r0.1",
                        initial.mesh.size.integer="1",
                        min.mesh.size.real=paste("r",sqrt(.Machine$double.eps),sep=""),
-                       min.mesh.size.integer=paste("r",sqrt(.Machine$double.eps),sep=""),
+                       min.mesh.size.integer="1", 
                        min.poll.size.real=paste("r",sqrt(.Machine$double.eps),sep=""),
-                       min.poll.size.integer=paste("r",sqrt(.Machine$double.eps),sep=""),
+                       min.poll.size.integer="1", 
                        opts=list(),
                        nmulti=0,
                        tau=NULL,
